
qconcurrency
============

This is simply a collection of tools for python bindings
of the Qt_ GUI library, that simplify running concurrent jobs.
I have built them specifically to address issues I commonly
run into (like needing to stop a *loading* thread automatically
when the user wants to interrupt it witha new load operation).

I am building this with the intention of it being a personal library,
but if you find it useful, please feel free to use and modify :).


See Sphinx documentation_ for more details.

.. _documentation: https://willjp.github.io/pyqconcurrency/




.. _Qt: https://www.qt.io/


